﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:oo="http://www.omnigroup.com/namespace/OmniOutliner/v3"
    xmlns:url="http://www.omnigroup.com/xslt/url"
    xmlns:date="http://www.ora.com/XSLTCookbook/namespaces/date"
    exclude-result-prefixes="oo url date">
   
<xsl:output method="xml" indent="yes"/>

<xsl:param name="use-embedded-images"/>
<xsl:param name="filename-prefix"/>
<xsl:param name="use-formatting">no</xsl:param>
<xsl:param name="h-string">h</xsl:param>
<xsl:param name="hour-string">hour</xsl:param>
<xsl:param name="hours-string">hours</xsl:param>
<xsl:param name="d-string">d</xsl:param>
<xsl:param name="day-string">day</xsl:param>
<xsl:param name="days-string">days</xsl:param>
<xsl:param name="w-string">w</xsl:param>
<xsl:param name="week-string">week</xsl:param>
<xsl:param name="weeks-string">weeks</xsl:param>
<!-- Column formatters --> 

<xsl:template match="oo:cell">
    <xsl:variable name="uri-prefix">
        <!-- only include filename-prefix for images and movies, ignore if already has file: prefix -->
        <xsl:choose>
            <xsl:when test="starts-with(@href,'file:')"></xsl:when>
            <xsl:when test="@type = 'image'"><xsl:value-of select="$filename-prefix"/></xsl:when>
            <xsl:when test="@type = 'movie'"><xsl:value-of select="$filename-prefix"/></xsl:when>
            <xsl:otherwise/>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="href">
        <xsl:value-of select="$uri-prefix"/><xsl:value-of select="@href"/>
    </xsl:variable>
    <xsl:variable name="filename">
        <xsl:variable name="refid" select="@refid"/>
        
        <xsl:choose>
            <xsl:when test="function-available('url:encode')">
                <xsl:value-of select="$uri-prefix"/><xsl:value-of select="url:encode(/oo:outline/oo:attachments/oo:attachment[@id = $refid]/@href)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$uri-prefix"/><xsl:value-of select="/oo:outline/oo:attachments/oo:attachment[@id = $refid]/@href"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <!-- Images and movies want a single URL while vanilla links want both -->
    <xsl:variable name="filenameOrHref">
        <xsl:choose>
            <xsl:when test="$filename != ''">
                <xsl:value-of select="$filename"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$href"/>
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:variable>

    <xsl:choose>
        <xsl:when test="@type = 'image'">
            <xsl:call-template name="cell-image" >
                <xsl:with-param name="filename" select="$filenameOrHref"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:when test="@type = 'movie'">
            <xsl:call-template name="cell-movie" >
                <xsl:with-param name="filename" select="$filenameOrHref"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
            <xsl:call-template name="cell-link" >
                <xsl:with-param name="filename" select="$filename"/>
                <xsl:with-param name="href" select="$href"/>
            </xsl:call-template>
        </xsl:otherwise>    
    </xsl:choose>

</xsl:template>

<xsl:template name="cell-image">
    <xsl:param name="filename"/>

    <xsl:choose>
    
        <xsl:when test="@expanded = 'yes' and /oo:outline/oo:editor[@hide-attachment-tags != 'yes']">

            <table cellspacing="0" border="0" valign="middle" style="display: inline;" >
                <tr><td style="border:1px solid black;">
                    <div style="padding: 2px; background-color: #f1f1f1; border-bottom: 1px solid black;"><xsl:value-of select="@name"/></div>
                    <img height="{@height}" width="{@width}" style="vertical-align: middle;" src="{$filename}" alt="{@name}" />
                </td></tr>
            </table>

        </xsl:when>

        <xsl:when test="/oo:outline/oo:editor[@hide-attachment-tags = 'yes']">
            <img height="{@height}" width="{@width}" style="vertical-align: middle;" src="{$filename}" alt="{@name}" />
        </xsl:when>

        <xsl:otherwise>
            <span style="background-color: #f1f1f1;"><a href="{$filename}"><xsl:value-of select="@name"/></a></span>
        </xsl:otherwise>
    </xsl:choose>
    
    
</xsl:template>

<xsl:template name="cell-movie">
    <xsl:param name="filename"/>
    <xsl:choose>
    
        <xsl:when test="@expanded = 'yes' and /oo:outline/oo:editor[@hide-attachment-tags != 'yes']">

            <table cellspacing="0" border="0" valign="middle" style=" display: inline;" >
                <tr><td style="border:1px solid black; vertical-align: middle;">
                    <div style="padding: 2px; background-color: #f1f1f1; border-bottom: 1px solid black;"><xsl:value-of select="@name"/></div>

                    <object STANDBY="Data is loading..." 
                        classid="clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B" 
                        codebase="http://www.apple.com/qtactivex/qtplugin.cab" 
                        border="0">
                        <PARAM NAME="src" VALUE="{$filename}"/>
                        <param name="AUTOPLAY" value="false"/>
                        <param name="CONTROLLER" value="true"/>
                        <param name="height" value="{@height}" />
                        <xsl:if test="@width > 0">
                            <param name="width" value="{@width}" />
                        </xsl:if>
                        <xsl:element name="embed">
                            <xsl:attribute name="height"><xsl:value-of select="@height" /></xsl:attribute>
                            <xsl:if test="@width > 0">
                                <xsl:attribute name="width"><xsl:value-of select="@width" /></xsl:attribute>
                            </xsl:if>
                            <xsl:attribute name="src"><xsl:value-of select="$filename" /></xsl:attribute>
                            <xsl:attribute name="autoplay">false</xsl:attribute>
                            <xsl:attribute name="controller">true</xsl:attribute>
                            <xsl:attribute name="pluginspace">http://www.apple.com/quicktime/download/</xsl:attribute>
                        </xsl:element>
<!--
                        <EMBED height="{@height}" width="{@width}" src="{$filename}" autoplay="false" CONTROLLER="true" PLUGINSPAGE="http://www.apple.com/quicktime/download/"></EMBED>
-->
                    </object>
                </td></tr>
            </table>
        </xsl:when>

        <xsl:when test="/oo:outline/oo:editor[@hide-attachment-tags = 'yes']">
            <object STANDBY="Data is loading..." 
                classid="clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B" 
                codebase="http://www.apple.com/qtactivex/qtplugin.cab" 
                border="0">
                <PARAM NAME="src" VALUE="{$filename}"/>
                <param name="AUTOPLAY" value="false"/>
                <param name="CONTROLLER" value="true"/>
                <param name="height" value="{@height}" />
                <xsl:if test="@width > 0">
                    <param name="width" value="{@width}" />
                </xsl:if>
                <xsl:element name="embed">
                    <xsl:attribute name="height"><xsl:value-of select="@height" /></xsl:attribute>
                    <xsl:if test="@width > 0">
                        <xsl:attribute name="width"><xsl:value-of select="@width" /></xsl:attribute>
                    </xsl:if>
                    <xsl:attribute name="src"><xsl:value-of select="$filename" /></xsl:attribute>
                    <xsl:attribute name="autoplay">false</xsl:attribute>
                    <xsl:attribute name="controller">true</xsl:attribute>
                    <xsl:attribute name="pluginspace">http://www.apple.com/quicktime/download/</xsl:attribute>
                </xsl:element>
<!--
                <EMBED height="{@height}" width="{@width}" src="{$filename}" autoplay="false" CONTROLLER="true" PLUGINSPAGE="http://www.apple.com/quicktime/download/"></EMBED>
-->
            </object>
        </xsl:when>
        <xsl:otherwise>
            <span style="background-color: #f1f1f1;"><a href="{$filename}"><xsl:value-of select="@name"/></a></span>
        </xsl:otherwise>

    </xsl:choose>

</xsl:template>

<xsl:template name="cell-link">
    <xsl:param name="filename"/>
    <xsl:param name="href"/>
    <xsl:choose>
        <xsl:when test="$filename != '' and $href != ''">
            <span><a href="{$href}">
                <xsl:if test="$filename != ''">
                    <img valign="middle" alt="" border="0" src="{$filename}" />
                </xsl:if>
                <xsl:value-of select="@name"/>
            </a></span>
        </xsl:when>
        <xsl:when test="$filename != ''">
            <span><a href="{$filename}"><xsl:value-of select="@name"/></a></span>
        </xsl:when>
        <xsl:when test="$href != ''">
            <span><a href="{$href}"><xsl:value-of select="@name"/></a></span>
        </xsl:when>
    </xsl:choose>
</xsl:template>

<xsl:template match="oo:text">
    <xsl:apply-templates />
</xsl:template>

<xsl:template match="oo:p"> 
    <xsl:apply-templates />
    <br />
</xsl:template>

<xsl:template match="oo:run">

    <xsl:variable name="class">
        <xsl:for-each select="oo:style/oo:inherited-style">
            <xsl:variable name="style-name" select="@name" />
            <xsl:text> ns-</xsl:text><xsl:value-of select="translate($style-name,' &#x9;&#xa;','-')"/>
        </xsl:for-each>
    </xsl:variable>
	
    <xsl:variable name="classbackground">
        <xsl:for-each select="oo:style/oo:inherited-style">
            <xsl:variable name="style-name" select="@name" />
            <xsl:text> ns-bg-</xsl:text><xsl:value-of select="translate($style-name,' &#x9;&#xa;','-')"/>
        </xsl:for-each>
    </xsl:variable>
    
    <xsl:variable name="styles">
        <xsl:call-template name="apply-styles" />
		</xsl:variable>
		
	<xsl:variable name="background">
		<xsl:call-template name="apply-background" />
		</xsl:variable>
		
	<xsl:variable name="textalignment">
		<xsl:call-template name="text-align" ></xsl:call-template>
	</xsl:variable>
	
	
	<xsl:choose>
		<!-- if there's text alignment applied at text insertion  
		
		******NYI***** 
		
		-->
		<xsl:when test="$textalignment = 'SKIP'">
			<div>
				<xsl:attribute name="style">
					<xsl:value-of select="$textalignment" />
					</xsl:attribute>
				
				<xsl:choose>
					<!-- If we've got a class or style to apply then use a span -->
					<!--xsl:when test="$class != '' or $styles != '' or $background != '' or $classbackground != ''">
						<span>
							<xsl:attribute name="class">
								<xsl:if test="$class != ''">
									<xsl:value-of select="$class" />
								</xsl:if>
								<xsl:if test="$classbackground != ''">
									<xsl:value-of select="$classbackground" />
									</xsl:if>
								</xsl:attribute>
							
							<xsl:attribute name="style">
								<xsl:if test="$styles != ''">
									<xsl:value-of select="$styles" />
									</xsl:if>
								<xsl:if test="$background != ''">
									<xsl:value-of select="$background" /> 
									</xsl:if>
								</xsl:attribute>
							</span>
						</xsl:when-->
					
					<!-- Otherwise just emit the text -->
					
					<xsl:otherwise>
						<xsl:apply-templates />
						</xsl:otherwise>
					</xsl:choose>
				</div>
			</xsl:when>
		<xsl:otherwise>
			
			<xsl:choose>
				
				<!-- If we've got a class or style to apply then use a span -->
				<xsl:when test="$class != '' or $styles != '' or $background != '' or $classbackground != ''">
					<span>
							<xsl:attribute name="class">
								<xsl:if test="$class != ''">
									<xsl:value-of select="$class" />
								</xsl:if>
								<xsl:if test="$classbackground != ''">
									<xsl:value-of select="$classbackground" />
									</xsl:if>
								</xsl:attribute>
							
							<xsl:attribute name="style">
								<xsl:if test="$styles != ''">
									<xsl:value-of select="$styles" />
									</xsl:if>
								<xsl:if test="$background != ''">
									<xsl:value-of select="$background" /> 
									</xsl:if>
								</xsl:attribute>
						
						<xsl:apply-templates />
						
						
						</span>
					</xsl:when>
				
				<!-- Otherwise just emit the text -->
				
				<xsl:otherwise>
					
					<xsl:apply-templates />
					
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	
	</xsl:template>
	
<xsl:template match="oo:lit">
	<!-- possible for a space character to end up in its own run in the middle of a cell, this will write that space to the html -->
	<xsl:variable name="space">
		<xsl:value-of select="."/>
		</xsl:variable>
	<xsl:if test="$space = ''">
		<xsl:text> </xsl:text>
		</xsl:if>
    <xsl:apply-templates />
</xsl:template>

<xsl:template match="oo:enum">
    <xsl:if test="node()">
        <xsl:value-of select="text()"/>
    </xsl:if>
        
</xsl:template>

<xsl:template match="oo:duration">
    <xsl:param name="pos" />

    <!-- Takes a pre-formmated duration from OO -->
    <xsl:choose>
        <xsl:when test="$use-formatting = 'yes'">
            <xsl:variable name="item-column" select="/oo:outline/oo:columns/oo:column[not(@is-note-column) or @is-note-column != 'yes'][$pos]"/>
            <xsl:call-template name="format-duration">
                <xsl:with-param name="item-column" select="$item-column"/>
                <xsl:with-param name="number" select="text()"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="text()"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="oo:date">
    <xsl:param name="pos" />
    
    <!-- Takes a pre-formmated date from OO -->
    <xsl:choose>
        <xsl:when test="$use-formatting = 'yes'">
            <xsl:variable name="item-column" select="/oo:outline/oo:columns/oo:column[not(@is-note-column) or @is-note-column != 'yes'][$pos]"/>
            <xsl:call-template name="format-date">
                <xsl:with-param name="item-column" select="$item-column"/>
                <xsl:with-param name="number" select="text()"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="text()"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="oo:checkbox">
    <xsl:call-template name="empty-output"/>
    <xsl:call-template name="checkbox-image">
        <xsl:with-param name="checkbox-type" select="node()"/>
    </xsl:call-template>
</xsl:template>

<xsl:template match="oo:number">
    <xsl:param name="pos" />
    
    <!-- Takes a pre-formmated number from OO -->
    <xsl:choose>
        <xsl:when test="$use-formatting = 'yes'">
            <xsl:variable name="item-column" select="/oo:outline/oo:columns/oo:column[not(@is-note-column) or @is-note-column != 'yes'][$pos]"/>
            <xsl:call-template name="format-number">
                <xsl:with-param name="item-column" select="$item-column"/>
                <xsl:with-param name="number" select="text()"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="text()"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="format-generic">
    <xsl:param name="item-column"/>
    <xsl:param name="number"/>
    <xsl:choose>
        <xsl:when test="$item-column/oo:formatter and $item-column/oo:formatter/@type = 'date'">
            <xsl:call-template name="format-date">
                <xsl:with-param name="item-column" select="$item-column"/>
                <xsl:with-param name="number" select="$number"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:when test="$item-column/oo:formatter and $item-column/oo:formatter/@type = 'duration'">
            <xsl:call-template name="format-duration">
                <xsl:with-param name="item-column" select="$item-column"/>
                <xsl:with-param name="number" select="$number"/>
            </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
            <xsl:call-template name="format-number">
                <xsl:with-param name="item-column" select="$item-column"/>
                <xsl:with-param name="number" select="$number"/>
            </xsl:call-template>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="format-date">
    <xsl:param name="item-column"/>
    <xsl:param name="number"/>
    <!-- todo: implement date formatting -->
    <xsl:variable name="year" select="substring-before($number, '-')"/>
    <xsl:variable name="month" select="substring-before(substring-after($number, concat($year, '-')), '-')"/>
    <xsl:variable name="day" select="substring-before(substring-after($number, concat($year, '-', $month, '-')), ' ')"/>
    <xsl:variable name="hour" select="substring-before(substring-after($number, concat($year, '-', $month, '-', $day, ' ')), ':')"/>
    <xsl:variable name="minute" select="substring-before(substring-after($number, concat($year, '-', $month, '-', $day, ' ', $hour, ':')), ':')"/>
    <xsl:variable name="second" select="substring-before(substring-after($number, concat($year, '-', $month, '-', $day, ' ', $hour, ':', $minute, ':')), ' ')"/>
    <xsl:variable name="time-zone" select="substring-after($number, concat($year, '-', $month, '-', $day, ' ', $hour, ':', $minute, ':', $second, ' '))"/>
    <xsl:variable name="format">
        <xsl:choose>
            <xsl:when test="$item-column/oo:formatter and $item-column/oo:formatter/@type = 'date'">
                <xsl:value-of select="$item-column/oo:formatter/text()"/>
            </xsl:when>
            <xsl:otherwise>
                %Y-%m-%d
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <xsl:call-template name="date:format-date-time">
        <xsl:with-param name="year" select="$year"/>
        <xsl:with-param name="month" select="$month"/>
        <xsl:with-param name="day" select="$day"/>
        <xsl:with-param name="hour" select="$hour"/>
        <xsl:with-param name="minute" select="$minute"/>
        <xsl:with-param name="second" select="$second"/>
        <xsl:with-param name="time-zone" select="$time-zone"/>
        <xsl:with-param name="format" select="$format"/>
    </xsl:call-template>
    <!--<xsl:value-of select="$number"/>-->
</xsl:template>
    
<xsl:template name="format-duration">
    <xsl:param name="item-column"/>
    <xsl:param name="number"/>
    <xsl:choose>
        <xsl:when test="$item-column/oo:formatter and $item-column/oo:formatter/@type = 'duration'">
            <xsl:variable name="should-use-verbose-format" select="$item-column/oo:formatter/@should-use-verbose-format = 'yes'"/>
            <xsl:variable name="hours-per-day" select="$item-column/oo:formatter/@hours-per-day"/>
            <xsl:variable name="hours-per-week" select="$item-column/oo:formatter/@hours-per-week"/>
            <xsl:variable name="hours-per-month" select="$item-column/oo:formatter/@hours-per-month"/>
            <xsl:variable name="weeks" select="floor($number div $hours-per-week)"/>
            <xsl:variable name="w-remains" select="$number mod $hours-per-week"/>
             
            <xsl:variable name="days" select="floor($w-remains div $hours-per-day)"/>
            <xsl:variable name="d-remains" select="$w-remains mod $hours-per-day"/>
            
            
            <xsl:variable name="hours" select="format-number($d-remains, '0.####;-0.####')"/>
            
            <xsl:if test="$weeks > 0">
                <xsl:variable name="duration-string">
                    <xsl:choose>
                        <xsl:when test="$should-use-verbose-format">
                            <xsl:text> </xsl:text>
                            <xsl:choose>
                                <xsl:when test="$weeks > 1">
                                    <xsl:value-of select="$weeks-string"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$week-string"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="$w-string"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <xsl:value-of select="$weeks"/><xsl:value-of select="$duration-string"/><xsl:text> </xsl:text>
            </xsl:if>
            <xsl:if test="$days > 0">
                <xsl:variable name="duration-string">
                    <xsl:choose>
                        <xsl:when test="$should-use-verbose-format">
                            <xsl:text> </xsl:text>
                            <xsl:choose>
                                <xsl:when test="$days > 1">
                                    <xsl:value-of select="$days-string"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$day-string"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="$d-string"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <xsl:value-of select="$days"/><xsl:value-of select="$duration-string"/><xsl:text> </xsl:text>
            </xsl:if>
            <xsl:if test="$hours > 0">
                <xsl:variable name="duration-string">
                    <xsl:choose>
                        <xsl:when test="$should-use-verbose-format">
                            <xsl:text> </xsl:text>
                            <xsl:choose>
                                <xsl:when test="$hours > 1">
                                    <xsl:value-of select="$hours-string"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$hour-string"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="$h-string"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <xsl:value-of select="$hours"/><xsl:value-of select="$duration-string"/><xsl:text> </xsl:text>
            </xsl:if>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="$number"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>
    
<xsl:template name="format-number">
    <xsl:param name="item-column"/>
    <xsl:param name="number"/>
    <xsl:choose>
        <xsl:when test="$item-column/oo:formatter and $item-column/oo:formatter/@type = 'number'">
            <xsl:variable name="new-number">
                <xsl:choose>
                    <xsl:when test="contains($item-column/oo:formatter,'%')"><xsl:value-of select="$number div 100"/></xsl:when>
                    <xsl:otherwise><xsl:value-of select="$number"/></xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <!-- need to remove the zero formatter used -->
            <xsl:variable name="positive-format" select="substring-before($item-column/oo:formatter, ';')"/>
            <xsl:variable name="zero-format" select="substring-after($item-column/oo:formatter, ';')"/>
            <xsl:variable name="negative-format" select="substring-after($zero-format, ';')"/>
            <xsl:variable name="format"><xsl:value-of select="$positive-format"/>;<xsl:value-of select="$negative-format"/></xsl:variable>
            <xsl:value-of select="format-number(number($new-number), $format)"/>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="$number"/>
        </xsl:otherwise>
    </xsl:choose>
    
</xsl:template>

<xsl:template name="checked-item-count">
    <xsl:param name="pos" />
    <xsl:param name="children-items"/>
    <xsl:variable name="count" select="count($children-items/oo:values/child::node()[$pos][name() = 'checkbox' and node() = 'checked'])"></xsl:variable>
    <xsl:variable name="temp-count" select="count($children-items/oo:children/oo:item)"/>
    <xsl:variable name="children-count">
        <xsl:choose>
            <xsl:when test="$temp-count > 0">
                <xsl:call-template name="checked-item-count">
                    <xsl:with-param name="pos" select="$pos" />
                    <xsl:with-param name="children-items" select="$children-items/oo:children/oo:item" />
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>0</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="$count + $children-count"/>
</xsl:template>

<xsl:template name="sum-child-items">
    <xsl:param name="pos" />
    <xsl:param name="children-items"/>
    <xsl:variable name="value">
        <xsl:value-of select="sum($children-items/oo:values/child::node()[$pos][name() != 'null'])"/>
    </xsl:variable>
    <xsl:variable name="children-value">
        <xsl:choose>
            <xsl:when test="count($children-items/oo:children/oo:item) > 0">
                <xsl:call-template name="sum-child-items">
                    <xsl:with-param name="pos" select="$pos" />
                    <xsl:with-param name="children-items" select="$children-items/oo:children/oo:item" />
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>0</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="$value + $children-value"/>
</xsl:template>

<xsl:template  name="child-item-count">
    <xsl:param name="pos" />
    <xsl:param name="children-items"/>
    <xsl:variable name="count" select="count($children-items/oo:values/child::node()[$pos][name() != 'null'])"></xsl:variable>
    <xsl:variable name="temp-count" select="count($children-items/oo:children/oo:item/oo:values/child::node()[$pos][name() != 'null'])"/>
    <xsl:variable name="children-count">
        <xsl:choose>
            <xsl:when test="$temp-count > 0">
                <xsl:call-template name="child-item-count">
                    <xsl:with-param name="pos" select="$pos" />
                    <xsl:with-param name="children-items" select="$children-items/oo:children/oo:item" />
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>0</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="$count + $children-count"/>
</xsl:template>
    
<xsl:template  name="minimum-child-item">
    <xsl:param name="pos" />
    <xsl:param name="children-items"/>
    <xsl:param name="sort-type"/>
    <xsl:variable name="min-item">
        <xsl:choose>
            <xsl:when test="$sort-type = 'text'">
                <xsl:for-each select="$children-items/oo:values/child::node()[$pos][name() != 'null']">
                    <xsl:sort data-type="text" order="ascending"/>
                    <xsl:if test="position()=1"><xsl:value-of select="."/></xsl:if>
                </xsl:for-each>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="$children-items/oo:values/child::node()[$pos][name() != 'null']">
                    <xsl:sort data-type="number" order="ascending"/>
                    <xsl:if test="position()=1"><xsl:value-of select="."/></xsl:if>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="child-item">
        <xsl:choose>
            <xsl:when test="count($children-items/oo:children/oo:item) > 0">
                <xsl:call-template name="minimum-child-item">
                    <xsl:with-param name="pos" select="$pos" />
                    <xsl:with-param name="children-items" select="$children-items/oo:children/oo:item" />
                    <xsl:with-param name="sort-type" select="$sort-type"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="$min-item"/></xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:choose>
        <xsl:when test="$child-item >= $min-item">
            <xsl:value-of select="$min-item"/>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="$child-item"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>
    
<xsl:template  name="maximum-child-item">
    <xsl:param name="pos" />
    <xsl:param name="children-items"/>
    <xsl:param name="sort-type"/>
    <xsl:variable name="max-item">
        <xsl:choose>
            <xsl:when test="$sort-type = 'text'">
                <xsl:for-each select="$children-items/oo:values/child::node()[$pos][name() != 'null']">
                    <xsl:sort data-type="text" order="descending"/>
                    <xsl:if test="position()=1"><xsl:value-of select="."/></xsl:if>
                </xsl:for-each>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="$children-items/oo:values/child::node()[$pos][name() != 'null']">
                    <xsl:sort data-type="number" order="descending"/>
                    <xsl:if test="position()=1"><xsl:value-of select="."/></xsl:if>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:variable>
    <xsl:variable name="child-item">
        <xsl:choose>
            <xsl:when test="count($children-items/oo:children/oo:item) > 0">
                <xsl:call-template name="maximum-child-item">
                    <xsl:with-param name="pos" select="$pos" />
                    <xsl:with-param name="children-items" select="$children-items/oo:children/oo:item" />
                    <xsl:with-param name="sort-type" select="$sort-type"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$max-item"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:choose>
        <xsl:when test="$max-item >= $child-item">
            <xsl:value-of select="$max-item"/>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="$child-item"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="checkbox-image">
    <xsl:param name="checkbox-type"/>
    <xsl:choose>
        <xsl:when test="$checkbox-type = 'unchecked'">
            <xsl:choose>
                <xsl:when test="$use-embedded-images='yes'">
                    <img align="center" border="0" hspace="2" vspace="0" alt="[ ]" class="unchecked-image" title="unchecked"/>
                </xsl:when>
                <xsl:otherwise>
                    <img align="center" border="0" hspace="2" vspace="0" alt="[ ]" src="Unchecked.png" />
                </xsl:otherwise>
            </xsl:choose>
        </xsl:when>
        <xsl:when test="$checkbox-type = 'checked'">
            <xsl:choose>
                <xsl:when test="$use-embedded-images='yes'">
                    <img align="center" border="0" hspace="2" vspace="0" alt="[x]" class="checked-image" title="checked"/>
                </xsl:when>
                <xsl:otherwise>
                    <img align="center" border="0" hspace="2" vspace="0" alt="[x]" src="Checked.png" />
                </xsl:otherwise>
            </xsl:choose>
        </xsl:when>
        <xsl:when test="$checkbox-type = 'mixed' or $checkbox-type = 'indeterminate'">
            <xsl:choose>
                <xsl:when test="$use-embedded-images='yes'">
                    <img align="center" border="0" hspace="2" vspace="0" alt="[-]" class="mixed-image" title="mixed"/>
                </xsl:when>
                <xsl:otherwise>
                    <img align="center" border="0" hspace="2" vspace="0" alt="[-]" src="Mixed.png" />
                </xsl:otherwise>
            </xsl:choose>
        </xsl:when>
    </xsl:choose>
</xsl:template>

<xsl:template name="empty-output">
    <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
</xsl:template>

<xsl:template match="oo:null">
    <xsl:param name="pos" />
    <xsl:param name="is-summary" />
    <xsl:param name="children-node"/>
    <xsl:variable name="item-column" select="/oo:outline/oo:columns/oo:column[not(@is-note-column) or @is-note-column != 'yes'][$pos]"/>
    <xsl:choose>
        <xsl:when test="$is-summary">
            <xsl:variable name="summary-value">
                <!-- calculate summary values -->
                <xsl:variable name="sort-type">
                    <xsl:choose>
                        <xsl:when test="$item-column/@type = 'date' or $item-column/@type = 'enumeration'">text</xsl:when>
                        <xsl:otherwise>number</xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <xsl:variable name="child-items" select="$children-node/oo:item"/>
                <xsl:choose>
                    <xsl:when test="$item-column/@summary = 'sum'">
                        <xsl:variable name="cell-count">
                            <xsl:call-template name="child-item-count">
                                <xsl:with-param name="pos" select="$pos" />
                                <xsl:with-param name="children-items" select="$child-items" />
                            </xsl:call-template>
                        </xsl:variable>
                        <xsl:variable name="total-sum">
                            <xsl:call-template name="sum-child-items">
                                <xsl:with-param name="pos" select="$pos" />
                                <xsl:with-param name="children-items" select="$child-items" />
                            </xsl:call-template>
                        </xsl:variable>
                        <xsl:if test="$cell-count > 0">
                            <xsl:value-of select="$total-sum"/>
                        </xsl:if>
                    </xsl:when>
                    <xsl:when test="$item-column/@summary = 'average'">
                        <xsl:variable name="cell-count">
                            <xsl:call-template name="child-item-count">
                                <xsl:with-param name="pos" select="$pos" />
                                <xsl:with-param name="children-items" select="$child-items" />
                            </xsl:call-template>
                        </xsl:variable>
                        <xsl:variable name="total-sum">
                            <xsl:call-template name="sum-child-items">
                                <xsl:with-param name="pos" select="$pos" />
                                <xsl:with-param name="children-items" select="$child-items" />
                            </xsl:call-template>
                        </xsl:variable>
                        <xsl:if test="$cell-count > 0">
                            <xsl:value-of select="$total-sum div $cell-count"/>
                        </xsl:if>
                    </xsl:when>
                    <xsl:when test="$item-column/@summary = 'minimum'">
                        <xsl:call-template name="minimum-child-item">
                            <xsl:with-param name="pos" select="$pos" />
                            <xsl:with-param name="children-items" select="$child-items" />
                            <xsl:with-param name="sort-type" select="$sort-type"/>
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:when test="$item-column/@summary = 'maximum'">
                        <xsl:call-template name="maximum-child-item">
                            <xsl:with-param name="pos" select="$pos" />
                            <xsl:with-param name="children-items" select="$child-items" />
                            <xsl:with-param name="sort-type" select="$sort-type"/>
                        </xsl:call-template>
                    </xsl:when>
                </xsl:choose>
            </xsl:variable>
            <xsl:choose>
                <xsl:when test="$item-column/@summary = 'state' and $is-summary">
                    <xsl:variable name="child-items" select="$children-node/oo:item"/>
                    <xsl:variable name="cell-count">
                        <xsl:call-template name="child-item-count">
                            <xsl:with-param name="pos" select="$pos" />
                            <xsl:with-param name="children-items" select="$child-items" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:variable name="checked-count">
                        <xsl:call-template name="checked-item-count">
                            <xsl:with-param name="pos" select="$pos" />
                            <xsl:with-param name="children-items" select="$child-items" />
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:call-template name="empty-output"/>
                    <xsl:choose>
                        <xsl:when test="$checked-count > 0 and $cell-count = number($checked-count)">
                            <xsl:call-template name="checkbox-image">
                                <xsl:with-param name="checkbox-type">checked</xsl:with-param>
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:when test="$checked-count > 0 and $cell-count > $checked-count">
                            <xsl:call-template name="checkbox-image">
                                <xsl:with-param name="checkbox-type">mixed</xsl:with-param>
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:call-template name="checkbox-image">
                                <xsl:with-param name="checkbox-type">unchecked</xsl:with-param>
                            </xsl:call-template>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:choose>
                        <xsl:when test="$summary-value and $summary-value != ''">
                            <xsl:call-template name="format-generic">
                                <xsl:with-param name="item-column" select="$item-column"/>
                                <xsl:with-param name="number" select="$summary-value"/>
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:call-template name="empty-output"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
            <!-- show empty checkbox if null item is in a checkbox column -->
            <xsl:if test="$item-column/@type='checkbox'">
                <xsl:call-template name="empty-output"/>
                <xsl:call-template name="checkbox-image">
                    <xsl:with-param name="checkbox-type">unchecked</xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

</xsl:stylesheet>
