<?xml version="1.0" encoding="utf-8"?>

<!--
 
 Basic HTML export for OmniOutliner3.
 
 Uses HTML 4.01 Transitional
 
 Uses nested DIVs with single-row tables as a way to simultaneously nest things and get fixed-width columns.
 
 FEATURES:
 * column ordering
 * column width
 * checkbox status/visibility
 * row visibility
 * formats number columns using outliners formats
 * checkbox columns
 * duration columns (honors duration settings)
 * date columns using outliner's formatters
 * document-wide styles: background color, font-family, grid color
 * column/header alignment
 
 -->

<xsl:stylesheet version="1.0" 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:oo="http://www.omnigroup.com/namespace/OmniOutliner/v3"
    exclude-result-prefixes="oo"
	>
	
	<xsl:import href="image.xsl" />
	<xsl:import href="date.date-time.xslt"/>
	<xsl:import href="style-formatters.xsl" />
	<xsl:import href="column-formatters.xsl" />
	
	<xsl:output method="html"
	version="4.01"
	encoding="utf-8"
	doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
	indent="yes"/>
	
	<xsl:param name="use-embedded-images"/>
	
	<xsl:strip-space elements="*" />
	
	<!-- Setup: calculate the position of the outline value in the values array (ignoring the notes column since its value is in <note> instead of <values> -->
	<xsl:variable name="non-note-columns" select="oo:outline/oo:columns/oo:column[not(@is-note-column) or @is-note-column != 'yes']" />
	
	<xsl:variable name="table-width" select="sum($non-note-columns/@width) + floor(sum($non-note-columns/@width) * 0.15)" />
	
	<!-- Go thru all the columns and determine which one is the topic column -->
	<xsl:variable name="outline-column-position">
		<xsl:for-each select="$non-note-columns">
			<xsl:if test="@is-outline-column = 'yes'">
				<xsl:value-of select="position()"/>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
	
	<!-- Grab some document settings -->
	<xsl:variable name="is-status-visible">
		<xsl:value-of select="/oo:outline/oo:editor/@status-visible"/>
		</xsl:variable>
	
	<!-- Add JavaScript inline if using embedded images -->
	<xsl:template name="embedJS">
		<script language="javascript" type="text/javascript">
			<![CDATA[
				<!--
				function hover(iNode, over) {
				
                if (over) {
				t = document.getElementById(iNode).alt;
				
				if (t == '*') {
				document.getElementById(iNode).className='handle-image';
				} else if (t == 'V') {
				document.getElementById(iNode).className='collapse-image';
				} else {
				document.getElementById(iNode).className='expand-image';
				}
                } else {
				document.getElementById(iNode).className='blank-image';
                }
				}
				
				function expand(ioNode) {
                ioWedge = "i" + ioNode.substr(1);
				
                if (document.getElementById && document.getElementById(ioNode) !=  null) {
				
				document.getElementById(ioNode).className='expanded';
				
				if (document.getElementById(ioWedge) !=  null) {        
				document.getElementById(ioWedge).className='collapse-image';
				document.getElementById(ioWedge).title='collapse';
				document.getElementById(ioWedge).alt='V';
				}
                }
				}
				
				function collapse(ioNode) {
                ioWedge = "i" + ioNode.substr(1);
				
                if (document.getElementById && document.getElementById(ioNode) != null) {
				
				document.getElementById(ioNode).className='collapsed';
				
				if (document.getElementById(ioWedge) !=  null) {        
				document.getElementById(ioWedge).className='expand-image';
				document.getElementById(ioWedge).title='expand';
				document.getElementById(ioWedge).alt='>';
				}
                }
				}
				
				function ioSwitch(ioNode,fully) {
				
                if (document.getElementById && document.getElementById(ioNode) !=  null) {
				nodeState = document.getElementById(ioNode).className;
                }
				
                if (nodeState == 'collapsed') {
				if (fully) {
				expandAll();
				} else {
				expand(ioNode);
				}
                }
				
                else {
				if (fully) {
				collapseAll();
				} else {
				collapse(ioNode);
				}
                }
				}
				
				function expandAll() {
				
                if (document.getElementsByTagName) {
				nodeList = document.getElementsByTagName('div');
				
				for (var i = 0; i < nodeList.length; i++) {
				
				if (nodeList.item(i).className == 'expanded' || nodeList.item(i).className == 'collapsed') {
				expand(nodeList.item(i).id);    
				}
				}
                }
				
                else {
				alert ("Sorry, don't know how to make this run in your browser.");
                }
				}
				
				function collapseAll() {
				
                if (document.getElementsByTagName) {
				nodeList = document.getElementsByTagName('div');
				
				for (var i = 0; i < nodeList.length; i++) {
				
				if (nodeList.item(i).className == 'expanded' || nodeList.item(i).className == 'collapsed') {
				collapse(nodeList.item(i).id);  
				}
				}
                }
				
                else {
				alert ("Sorry, don't know how to make this run in your browser.");
                }
				}
				-->
				]]>
			</script>
		</xsl:template>
	
	
	<xsl:template match="/">
		<html>
			<head>
				<!-- TODO- Also add a parameter for whether to put the styled document title in the body? -->
				<title><xsl:value-of select="/oo:outline/oo:outline-title/oo:text/oo:p/oo:run/oo:lit"/></title>
				<xsl:choose>
					<xsl:when test="$use-embedded-images='yes'">
						<xsl:call-template name="embedJS" />
						</xsl:when>
					<xsl:otherwise>
						<script type="text/javascript" src="outliner.js" />
						</xsl:otherwise>
					</xsl:choose>
				<xsl:call-template name="globalCSS" />
				</head>
			<body class="wholeDocument">
				<table cellspacing="0" cellpadding="0" class="top-right-border">
					<tr><td class="wholething no-border">
						<xsl:apply-templates select="oo:outline/oo:columns"/>
						<xsl:apply-templates select="oo:outline/oo:root/oo:item" >
							<xsl:with-param name="current-indentation" select="0"/>
							</xsl:apply-templates>
						</td></tr>
					</table>
				</body>
			</html>
		</xsl:template>
	
	<xsl:template match="notefill">
		<td></td>
		</xsl:template>
	
	<xsl:template match="oo:item">
		<xsl:param name="current-indentation"/>
		
		<!-- list out our row values -->
		<xsl:call-template name="values" >
			<xsl:with-param name="current-indentation" select="$current-indentation"/>
			<xsl:with-param name="uid" select="@id"/>
			</xsl:call-template>
		
		<!-- recursively list out the children -->
		<xsl:call-template name="procChildren">
			<xsl:with-param name="current-indentation" select="$current-indentation + 1"/>
			<xsl:with-param name="uid" select="@id"/>
			</xsl:call-template>
		</xsl:template>
	
	<xsl:template name="procChildren">
		<xsl:param name="current-indentation"/>
		<xsl:param name="uid"/>
		
		<xsl:for-each select="oo:children">
			
			<!--        <xsl:comment> Begin group <xsl:value-of select="$uid"/></xsl:comment> -->
			
			<div id="p{$uid}">
				<!-- set our expand/collapse state -->
				<xsl:attribute name="class">
					<xsl:choose>
						<xsl:when test="../@expanded = 'yes'"><xsl:text>expanded</xsl:text></xsl:when>
						<xsl:otherwise><xsl:text>collapsed</xsl:text></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				
				<xsl:apply-templates>
					<xsl:with-param name="current-indentation" select="$current-indentation"/>
					</xsl:apply-templates>
				</div>
			
			<!--        <xsl:comment> End group <xsl:value-of select="$uid"/> </xsl:comment> -->
			
			</xsl:for-each>
		</xsl:template>
	
	<xsl:template name="values">
		<xsl:param name="current-indentation" />
		<xsl:param name="uid"/>
		
		<xsl:variable name="aos" select="ancestor-or-self::oo:item"/>
		
		<xsl:variable name="style">
			<!-- walk up the tree to grab the styles of our ancestors. -->
			<xsl:for-each select="$aos">
				<xsl:sort select="position()" order="ascending" data-type="number"/>
				<xsl:variable name="pos" select="count($aos) - position() + 1" />
				
				<xsl:call-template name="apply-styles">
					<xsl:with-param name="start-node" select="oo:style[$pos]"/>
					</xsl:call-template>
				
				</xsl:for-each>
			</xsl:variable>
		
		
		<xsl:variable name="background">
			<!-- walk up the tree to grab the background color of our ancestors. -->
			<xsl:for-each select="$aos">
				<xsl:sort select="position()" order="ascending" data-type="number"/>
				<xsl:variable name="pos" select="count($aos) - position() + 1" />
				
				<xsl:call-template name="apply-background">
					<xsl:with-param name="start-node" select="oo:style[$pos]"/>
					</xsl:call-template>
				
				</xsl:for-each>
			</xsl:variable>
		
		
		<xsl:variable name="gutter">
			<!-- walk up the tree to grab the gutter color of our ancestors. -->
			<xsl:for-each select="$aos">
				<xsl:sort select="position()" order="ascending" data-type="number"/>
				<xsl:variable name="pos" select="count($aos) - position() + 1" />
				
				<xsl:call-template name="apply-gutter">
					<xsl:with-param name="start-node" select="oo:style[$pos]"/>
					</xsl:call-template>
				
				</xsl:for-each>
			</xsl:variable>
		
		<!-- don't know how to grab the correct indents of the ancestors yet -->
		<!--xsl:variable name="indent">
		 <xsl:for-each select="$aos">
		 <xsl:sort select="position()" order="ascending" data-type="number"/>
		 <xsl:variable name="pos" select="count($aos) - position() + 1" />
		 
		 <xsl:call-template name="child-indent">
		 <xsl:with-param name="start-node" select="oo:style[$pos]"/>
		 </xsl:call-template>
		 
		 </xsl:for-each>
		 </xsl:variable-->
		
		
		<xsl:variable name="named-styles">
			<!-- walk up the tree to grab the named styles of our ancestors. -->
			<xsl:for-each select="$aos">
				<xsl:sort select="position()" order="ascending" data-type="number"/>
				<xsl:variable name="pos" select="count($aos) - position() + 1" />
				
				<xsl:for-each select="oo:style[$pos]/oo:inherited-style">
					<xsl:variable name="style-name" select="@name" />
					<xsl:text> ns-</xsl:text><xsl:value-of select="translate($style-name,' &#x9;&#xa;','-')"/>
					</xsl:for-each>			
				</xsl:for-each>
			</xsl:variable>
		
		<xsl:variable name="named-styles-background">
			<!-- walk up the tree to grab the named styles background colors of our ancestors. -->
			<xsl:for-each select="$aos">
				<xsl:sort select="position()" order="ascending" data-type="number"/>
				<xsl:variable name="pos" select="count($aos) - position() + 1" />
				
				<xsl:for-each select="oo:style[$pos]/oo:inherited-style">
					<xsl:variable name="style-name" select="@name" />
					<xsl:text> ns-bg-</xsl:text><xsl:value-of select="translate($style-name,' &#x9;&#xa;','-')"/>
					</xsl:for-each>			
				</xsl:for-each>
			</xsl:variable>
		
		<xsl:variable name="named-styles-gutter">
			<!-- walk up the tree to grab the named styles gutter colors of our ancestors. -->
			<xsl:for-each select="$aos">
				<xsl:sort select="position()" order="ascending" data-type="number"/>
				<xsl:variable name="pos" select="count($aos) - position() + 1" />
				
				<xsl:for-each select="oo:style[$pos]/oo:inherited-style">
					<xsl:variable name="style-name" select="@name" />
					<xsl:text> ns-gutter-</xsl:text><xsl:value-of select="translate($style-name,' &#x9;&#xa;','-')"/>
					</xsl:for-each>			
				</xsl:for-each>
			</xsl:variable>
		
		<!-- gotta figure out if should draw our drag handle or not. -->
		
		<xsl:variable name="draw-handle">
			<xsl:call-template name="valueForKey">
				<xsl:with-param name="aos" select="$aos" />
				<xsl:with-param name="current-indentation" select="$current-indentation" />
				<xsl:with-param name="keyName" select="'item-handle-mode(com.omnigroup.OmniOutliner)'" />
				<xsl:with-param name="default" select="'always'" />
				</xsl:call-template>
			</xsl:variable>
		
		<xsl:variable name="use-labeling">
			<xsl:call-template name="numbering" >
				<xsl:with-param name="aos" select="$aos" />
				<xsl:with-param name="current-indentation" select="$current-indentation" />
				</xsl:call-template>
			</xsl:variable>
		
		
		<xsl:variable name="hanging-indent">
			<xsl:choose>
				<xsl:when test="$is-status-visible != 'no'">
					<xsl:text>32</xsl:text>
					</xsl:when>
				<xsl:otherwise>
					<xsl:text>17</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
		
		<table cellspacing="0" border="0" cellpadding="0" width="{$table-width}" class="row heighthack">
			<tr>
				
				<xsl:for-each select="oo:values/*">
					
					<xsl:variable name="pos" select="position()" />
					<xsl:variable name="item-column" select="/oo:outline/oo:columns/oo:column[not(@is-note-column) or @is-note-column != 'yes'][$pos]"/>
					<xsl:variable name="is-summary" select="$item-column/@summary and ($item-column/@summary != 'hidden' and $item-column/@summary != 'none' and $item-column/@summary != '') and count(../../oo:children/oo:item) > 0" />
					
					<!-- walk thru each value -->
					<td>
						
						
						<!-- If we've got a note and it's expanded then dig deeper -->
						<!--xsl:if test="(../../oo:note) and (../../oo:note[@expanded = 'yes']) and (position() != $outline-column-position)"-->
						<!-- If the column is before the topic *or* it's after the topic and we're not spanning columns then take up two rows -->
						<!--xsl:if test="(position() &lt; $outline-column-position) or
						 ( (position() != $outline-column-position) and (/oo:outline/oo:editor[not(@inline-notes-span = 'full')]) )
						 "-->
						<!--xsl:if test="(position() &lt; $outline-column-position)">
						 <xsl:attribute name="rowspan">
						 <xsl:text>2</xsl:text>
						 </xsl:attribute>
						 </xsl:if>
						 </xsl:if-->
						
						<xsl:attribute name="class">
							<!-- add out column style putting both col and colbackground here so non-topic columns received all styles-->
							<xsl:text> col</xsl:text>
							<xsl:value-of select="position()"/>
							<xsl:text> colbackground</xsl:text>
							<xsl:value-of select="position()"/>
							<!-- add out column width -->
							<xsl:text> col_width</xsl:text>
							<xsl:value-of select="position()"/>
							
							</xsl:attribute>
						
						<xsl:attribute name="style">
							<xsl:if test="(../../oo:note) and (position() = $outline-column-position)  and (../../oo:note[@expanded = 'yes'])">
								<xsl:text>border-bottom: none;</xsl:text>
								</xsl:if>
							
							</xsl:attribute>
						
						
						<!-- enter a div around the table for the cells to apply row styles-->
						<div> <!-- set height of column to 100%-->
							<xsl:attribute name="class">
								<xsl:text> full</xsl:text>
								<!-- add level style--> 
								<xsl:text> levelcolor</xsl:text>
								<xsl:value-of select="$current-indentation + 1"/>
								
								<xsl:value-of select="$named-styles-background"/>
								</xsl:attribute>
							
							<xsl:if test="$background != ''">
								<xsl:attribute name="style">
									<xsl:value-of select="$background" /> 
									</xsl:attribute>
								</xsl:if>
							
							
							<!-- if we're operating on our topic column ... -->
							<xsl:choose>
								<xsl:when test="position() = $outline-column-position">
									
									<table border="0" cellspacing="0" cellpadding="0" style="height:100%">
										<xsl:attribute name="class">
											<!-- add out column width -->
											<xsl:text> wide</xsl:text>
											<xsl:text> col</xsl:text>
											<xsl:value-of select="position()"/>
											</xsl:attribute>
										
										<!-- add cell for the drag handle and checkbox -->
										<tr>
											<!-- this cell is for the row indent, level 1 rows will have a 9px width to add spacing -->
											<td>   
												<xsl:attribute name="class">
													<!-- add out column style -->
													<xsl:text> subcell </xsl:text>
													<!-- add level style--> 
													<xsl:text> level</xsl:text>
													<xsl:value-of select="$current-indentation + 1"/>
													<xsl:text> levelguttercolor</xsl:text>
													<xsl:value-of select="$current-indentation + 1"/>
													
													<xsl:value-of select="$named-styles"/>
													<xsl:value-of select="$named-styles-gutter"/>
													</xsl:attribute>
												
												<xsl:attribute name="style">
													<xsl:text>width: </xsl:text>
													<!-- figure in indentation, base 9px -->
													<xsl:value-of select="($current-indentation * 16) + 9" />
													<xsl:text>px;</xsl:text> 
													
													<xsl:if test="$gutter != ''">
														<xsl:value-of select="$gutter" /> 
														</xsl:if>
													</xsl:attribute>
												</td>
											
											<!-- if handle is set to none and checkboxes are hidden, don't create this cell -->
											<xsl:if test="(not((substring($draw-handle, (string-length($draw-handle) - string-length('never')) + 1) = 'never') and ($is-status-visible = 'no')))">
												<td>   
													<xsl:attribute name="class">
														<!-- add out column style -->
														<xsl:text> subcell indicator</xsl:text>
														<!-- add level style--> 
														<xsl:text> level</xsl:text>
														<xsl:value-of select="$current-indentation + 1"/>
														<xsl:text> levelguttercolor</xsl:text>
														<xsl:value-of select="$current-indentation + 1"/>
														
														<xsl:value-of select="$named-styles"/>
														<xsl:value-of select="$named-styles-gutter"/>
														</xsl:attribute>
													
													<xsl:attribute name="style">
														<xsl:text>width: </xsl:text>
														<xsl:choose>
															<!-- since we should only be in here if one or both the handle and checkbox is there, we only need to check for the status of one -->
															<xsl:when test="(substring($draw-handle, (string-length($draw-handle) - string-length('never')) + 1) = 'never')">
																<xsl:text>13</xsl:text>
																</xsl:when>
															<xsl:when test="$is-status-visible = 'no'">
																<xsl:text>15</xsl:text>
																</xsl:when>
															<xsl:otherwise>
																<xsl:text>28</xsl:text>
																</xsl:otherwise>
															</xsl:choose>
														<xsl:text>px;</xsl:text> 
														
														<xsl:if test="$gutter != ''">
															<xsl:value-of select="$gutter" /> 
															</xsl:if>
														</xsl:attribute>
													
													<!-- if we have children we need to add a disclosure triangle otherwise add a bullet -->
													<xsl:choose>
														<xsl:when test="substring($draw-handle, (string-length($draw-handle) - string-length('always')) + 1) = 'always'">
															<xsl:choose>
																<xsl:when test="count(../../oo:children)">
																	<xsl:choose>
																		<xsl:when test="../../@expanded = 'yes'">
																			<xsl:choose>
																				<xsl:when test="$use-embedded-images='yes'">
																					<img onmousedown="ioSwitch('p{$uid}', event.shiftKey)" id="i{$uid}" style="margin-left: 3px; margin-right:3px;" border="0" alt="V" class="collapse-image" title="collapse" />
																					</xsl:when>
																				<xsl:otherwise>
																					<img onmousedown="ioSwitch('p{$uid}', event.shiftKey)" id="i{$uid}" style="margin-left: 3px; margin-right:3px;" border="0"  alt="V" src="Expanded.png" title="collapse" />
																					</xsl:otherwise>
																				</xsl:choose>
																			</xsl:when>
																		<xsl:otherwise>
																			<xsl:choose>
																				<xsl:when test="$use-embedded-images='yes'">
																					<img onmousedown="ioSwitch('p{$uid}', event.shiftKey)" id="i{$uid}" style="margin-left: 3px; margin-right:3px;" border="0" alt=">" class="expand-image" title="expand" />
																					</xsl:when>
																				<xsl:otherwise>
																					<img onmousedown="ioSwitch('p{$uid}', event.shiftKey)" id="i{$uid}" style="margin-left: 3px; margin-right:3px;" border="0" alt=">" src="Collapsed.png" title="expand" />
																					</xsl:otherwise>
																				</xsl:choose>
																			</xsl:otherwise>
																		</xsl:choose>
																	</xsl:when>
																<xsl:otherwise>
																	<xsl:choose>
																		<xsl:when test="$use-embedded-images='yes'">
																			<img border="0" style="margin-left: 3px; margin-right:3px;" alt="*" class="handle-image" />
																			</xsl:when>
																		<xsl:otherwise>
																			<img border="0" style="margin-left: 3px; margin-right:3px;" alt="*" src="LeafRowHandle.png" />
																			</xsl:otherwise>
																		</xsl:choose>
																	</xsl:otherwise>
																</xsl:choose>
															</xsl:when>
														<xsl:when test="substring($draw-handle, (string-length($draw-handle) - string-length('hover')) + 1) = 'hover'">
															<xsl:choose>
																<xsl:when test="count(../../oo:children)">
																	<xsl:choose>
																		<xsl:when test="../../@expanded = 'yes'">
																			<xsl:choose>
																				<xsl:when test="$use-embedded-images='yes'">
																					<img onmouseover="hover('i{$uid}', true)" onmouseout="hover('i{$uid}', false)" onmousedown="ioSwitch('p{$uid}', event.shiftKey)" id="i{$uid}" style="margin-left: 3px; margin-right:3px;" border="0" alt="V" class="blank-image" title="collapse" />
																					</xsl:when>
																				<xsl:otherwise>
																					<img onmouseover="hover('i{$uid}', true)" onmouseout="hover('i{$uid}', false)" onmousedown="ioSwitch('p{$uid}', event.shiftKey)" id="i{$uid}" style="margin-left: 3px; margin-right:3px;" border="0" alt="V" src="blank.png" title="collapse" />
																					</xsl:otherwise>
																				</xsl:choose>
																			</xsl:when>
																		<xsl:otherwise>
																			<xsl:choose>
																				<xsl:when test="$use-embedded-images='yes'">
																					<img onmouseover="hover('i{$uid}', true)" onmouseout="hover('i{$uid}', false)" onmousedown="ioSwitch('p{$uid}', event.shiftKey)" id="i{$uid}" style="margin-left: 3px; margin-right:3px;" border="0" alt=">" class="blank-image" title="expand" />
																					</xsl:when>
																				<xsl:otherwise>
																					<img onmouseover="hover('i{$uid}', true)" onmouseout="hover('i{$uid}', false)" onmousedown="ioSwitch('p{$uid}', event.shiftKey)" id="i{$uid}" style="margin-left: 3px; margin-right:3px;" border="0" alt=">" src="blank.png" title="expand" />
																					</xsl:otherwise>
																				</xsl:choose>
																			</xsl:otherwise>
																		</xsl:choose>
																	</xsl:when>
																<xsl:otherwise>
																	<xsl:choose>
																		<xsl:when test="$use-embedded-images='yes'">
																			<img onmouseover="hover('i{$uid}', true)" onmouseout="hover('i{$uid}', false)" id="i{$uid}" style="margin-left: 3px; margin-right:3px;" border="0" alt="*" class="blank-image leaf"/>
																			</xsl:when>
																		<xsl:otherwise>
																			<img onmouseover="hover('i{$uid}', true)" onmouseout="hover('i{$uid}', false)" id="i{$uid}" style="margin-left: 3px; margin-right:3px;" border="0" alt="*" src="blank.png" class="leaf"/>
																			</xsl:otherwise>
																		</xsl:choose>
																	</xsl:otherwise>
																</xsl:choose>
															</xsl:when>
														</xsl:choose>
													<!-- load our status checkbox -->
													<xsl:call-template name="status-checkbox">
														<!-- use the state of this values's parent item -->
														<xsl:with-param name="state" select="../../@state" />
														</xsl:call-template>
													</td>
												</xsl:if>
											
											
											<!-- cell for row labeling -->
											<xsl:if test="$use-labeling != ' '">
												<td>
													<xsl:attribute name="class">
														<!-- add out column style -->
														<xsl:text> subcell labelpadding</xsl:text>
														<!-- add level style--> 
														<xsl:text> level</xsl:text>
														<xsl:value-of select="$current-indentation + 1"/>
														<xsl:text> levelguttercolor</xsl:text>
														<xsl:value-of select="$current-indentation + 1"/>
														
														<xsl:value-of select="$named-styles"/>
														<xsl:value-of select="$named-styles-gutter"/>
														</xsl:attribute>
													
													
													<xsl:attribute name="style">
														<!-- hopefully all browsers let the cell expand to fit the text, there's no way to know how wide the cell needs to be -->
														<xsl:text> width: 1px; </xsl:text>
														<xsl:if test="$gutter != ''">
															<xsl:value-of select="$gutter" /> 
															</xsl:if>
														</xsl:attribute>
													
													<!-- If we have any row numbering directives take care of that now -->
													<xsl:call-template name="numbering" >
														<xsl:with-param name="aos" select="$aos" />
														<xsl:with-param name="current-indentation" select="$current-indentation" />
														</xsl:call-template>
													
													</td>
												</xsl:if>
											
											<td>
												<xsl:attribute name="class">
													<xsl:text> content</xsl:text>
													<!-- add level style--> 
													<xsl:text> level</xsl:text>
													<xsl:value-of select="$current-indentation + 1"/>
													
													<xsl:value-of select="$named-styles"/>
													
													<!-- add column style -->
													<xsl:text> subcell</xsl:text>
													</xsl:attribute>
												
												
												<xsl:if test="$style != ''">  <!-- this is the cell text style, might need to use this for text insertion styles, but need to not set a background-color -->
													<xsl:attribute name="style">
														<xsl:value-of select="$style" />
														</xsl:attribute>
													</xsl:if>
												
												<!-- Insert the column value -->
												<xsl:apply-templates select=".">
													<xsl:with-param name="pos" select="position()" />
													</xsl:apply-templates>
												
												</td>
											</tr></table>
									</xsl:when>
								
								<xsl:otherwise> <!-- additional columns created here -->
									<div>
										<xsl:attribute name="class">
											<!-- add column style -->
											<xsl:text>column</xsl:text>
											<xsl:if test="$is-summary">
												<xsl:text> summary_node</xsl:text>
												</xsl:if>
											
											<!-- add level style--> 
											<xsl:text> level</xsl:text>
											<xsl:value-of select="$current-indentation + 1"/>
											
											<xsl:value-of select="$named-styles"/>
											</xsl:attribute>
										
										<xsl:if test="$style != ''">  <!-- this is the cell text style, might need to use this for text insertion styles, but need to not set a background-color -->
											<xsl:attribute name="style">
												<xsl:value-of select="$style" />
												</xsl:attribute>
											</xsl:if>
										
										
										
										<!-- Insert the column value -->
										<xsl:apply-templates select=".">
											<xsl:with-param name="pos" select="position()" />
											<xsl:with-param name="is-summary" select="$is-summary" />
											<xsl:with-param name="children-node" select="../../oo:children"/>
											</xsl:apply-templates>
										</div>
									</xsl:otherwise>
								</xsl:choose>
							</div> <!-- end of div for row styles -->
						</td>
					</xsl:for-each>
				</tr>
			
			<!-- if we've got a note drop it in now -->
			
			<xsl:if test="(oo:note) and (oo:note[@expanded = 'yes'])">
				<tr>
					<!-- if there's columns to the left of the topic column, create filler cells -->						
					<xsl:for-each select="$non-note-columns">
						<xsl:if test="(position() &lt; $outline-column-position)">
							<td>
								<xsl:attribute name="class">
									<!-- add column style -->
									<xsl:text> colbackground</xsl:text>
									<xsl:value-of select="position()"/>
									</xsl:attribute>
								
								<div>
									<xsl:attribute name="class">
										<!-- add level style--> 
										<xsl:text> levelcolor</xsl:text>
										<xsl:value-of select="$current-indentation + 1"/>
										
										<xsl:value-of select="$named-styles-background"/>
										</xsl:attribute>
									
									<xsl:attribute name="style">
										<xsl:text>width: 100%; height: 100%; </xsl:text>
										<xsl:if test="$background != ''">  
											<xsl:value-of select="$background" />
											</xsl:if>
										</xsl:attribute>
									</div>
								</td>
							</xsl:if>
						</xsl:for-each>
					
					<td>
						<xsl:if test="(/oo:outline/oo:editor[(@inline-notes-span = 'full')])">
							<xsl:attribute name="colspan">
								<xsl:value-of select="$non-note-columns[position() = last()-1] - $outline-column-position"/>
								</xsl:attribute>
							</xsl:if>
						
						<xsl:attribute name="class">
							<!-- add level style -->
							<xsl:text> level</xsl:text>
							<xsl:value-of select="$current-indentation + 1"/>
							<!-- add outline column style -->
							<xsl:text> colbackground</xsl:text>
							<xsl:value-of select="$outline-column-position"/>
							
							<xsl:value-of select="$named-styles"/>
							</xsl:attribute>
						
						
						<xsl:if test="$style != ''">
							<xsl:attribute name="style">
								<xsl:value-of select="$style" />
								</xsl:attribute>
							</xsl:if>
						
						<xsl:if test="(/oo:outline/oo:editor[@inline-notes-span = 'full'])">
							<!-- Figure out how many columns we should span -->
							<xsl:attribute name="colspan">
								<xsl:value-of select="count($non-note-columns) - ($outline-column-position - 1)" />
								</xsl:attribute>
							</xsl:if>
						
						<!-- enter a div around the table for the cells to apply row styles-->
						<div> <!-- set height of column to 100%-->
							<xsl:attribute name="class">
								<xsl:text> full</xsl:text>
								<!-- add level style background color -->
								<xsl:text> levelcolor</xsl:text>
								<xsl:value-of select="$current-indentation + 1"/>
								</xsl:attribute>
							
							<xsl:if test="$background != ''">
								<xsl:attribute name="style">
									<xsl:value-of select="$background" /> 
									</xsl:attribute>
								</xsl:if>
							
							
							<table border="0" cellspacing="0" cellpadding="0">
								<xsl:attribute name="style">
									<xsl:text>width:100%</xsl:text>
									</xsl:attribute>
								<tr>
									<!-- add our spacing cells -->
									<td>
										<xsl:attribute name="style">
											<xsl:text>width: </xsl:text>
											<!-- figure in indentation * 16 px + 16 px for the handle + 16 px for the checkbox -->
											<xsl:value-of select="($current-indentation * 16) + 9" />
											<xsl:text>px;</xsl:text> 
											
											<xsl:if test="$gutter != ''">
												<xsl:value-of select="$gutter" /> 
												</xsl:if>
											
											</xsl:attribute>
										<xsl:attribute name="class">
											<xsl:text> subcell wholedocgutter</xsl:text>
											<xsl:text> levelguttercolor</xsl:text>
											<xsl:value-of select="$current-indentation + 1"/>
											<xsl:value-of select="$named-styles-gutter"/>
											</xsl:attribute>
										</td>
									
									<!-- if handle is set to none and checkboxes are hidden, don't create this cell -->
									<xsl:if test="(not((substring($draw-handle, (string-length($draw-handle) - string-length('never')) + 1) = 'never') and ($is-status-visible = 'no')))">
										<td>
											<xsl:attribute name="class">
												<!-- add out column style -->
												<xsl:text> subcell wholedocgutter</xsl:text>
												<xsl:text> levelguttercolor</xsl:text>
												<xsl:value-of select="$current-indentation + 1"/>
												<xsl:value-of select="$named-styles-gutter"/>
												</xsl:attribute>
											
											<xsl:attribute name="style">
												<xsl:text>width: </xsl:text>
												<xsl:choose>
													<!-- since we should only be in here if one or both the handle and checkbox is there, we only need to check for the status of one -->
													<xsl:when test="(substring($draw-handle, (string-length($draw-handle) - string-length('never')) + 1) = 'never')">
														<xsl:text>13</xsl:text>
														</xsl:when>
													<xsl:when test="$is-status-visible = 'no'">
														<xsl:text>15</xsl:text>
														</xsl:when>
													<xsl:otherwise>
														<xsl:text>28</xsl:text>
														</xsl:otherwise>
													</xsl:choose>
												<xsl:text>px;</xsl:text> 
												
												<xsl:if test="$gutter != ''">
													<xsl:value-of select="$gutter" /> 
													</xsl:if>
												</xsl:attribute>
											</td>
										</xsl:if>
									<!-- putting the row numbering here again as transparent text as it's the only way I can think of to match the width -->
									<xsl:if test="$use-labeling != ' '">
										<td>
											<xsl:attribute name="class">
												<xsl:text> subcell labelpadding wholedocgutter</xsl:text>
												<xsl:text> levelguttercolor</xsl:text>
												<xsl:value-of select="$current-indentation + 1"/>
												<xsl:value-of select="$named-styles-gutter"/>
												</xsl:attribute>
											
											<xsl:attribute name="style">
												<xsl:text> color: rgba(0,0,0,0); width: 1px; </xsl:text>
												<xsl:if test="$gutter != ''">
													<xsl:value-of select="$gutter" /> 
													</xsl:if>
												</xsl:attribute>
											<!-- If we have any row numbering directives take care of that now -->
											<xsl:call-template name="numbering" >
												<xsl:with-param name="aos" select="$aos" />
												<xsl:with-param name="current-indentation" select="$current-indentation" />
												</xsl:call-template>
											</td>
										</xsl:if>
									
									<!-- add spacing cell for note indent beyond the row's indent, lets us have a lined up gutter -->
									<td>
										<xsl:attribute name="class">
											<xsl:text> subcell</xsl:text>
											</xsl:attribute>
										<xsl:attribute name="style">
											<xsl:text>width: </xsl:text>
											<xsl:value-of select="16" />
											<xsl:text>px;</xsl:text> 
											
											</xsl:attribute>
										</td>
									<!-- add the note cell -->
									<td>
										<xsl:attribute name="class">
											<xsl:text>note subcell</xsl:text>
											</xsl:attribute>
										<xsl:apply-templates select="oo:note" />
										</td></tr>
								</table>
							</div>
						</td>
					
					<xsl:if test="(/oo:outline/oo:editor[not(@inline-notes-span = 'full')])">
						<xsl:for-each select="$non-note-columns">
							<xsl:if test="(position() > $outline-column-position)">
								<td>
									<xsl:attribute name="class">
										<!-- add column style -->
										<xsl:text> colbackground</xsl:text>
										<xsl:value-of select="position()"/>
										</xsl:attribute>
									
									<div>
										<xsl:attribute name="class">
											<!-- add level style--> 
											<xsl:text> levelcolor</xsl:text>
											<xsl:value-of select="$current-indentation + 1"/>
											
											<xsl:value-of select="$named-styles-background"/>
											</xsl:attribute>
										
										<xsl:attribute name="style">
											<xsl:text>width: 100%; height: 100%; </xsl:text>
											<xsl:if test="$background != ''">  
												<xsl:value-of select="$background" />
												</xsl:if>
											</xsl:attribute>
										</div>
									</td>
								</xsl:if>
							</xsl:for-each>
						</xsl:if>
					
					</tr>
				</xsl:if>
			
			</table>
		
		</xsl:template>
	
	<!-- get our column headers in there -->
	<xsl:template match="oo:columns">
		
		<xsl:if test="not(/oo:outline/oo:editor[@column-titles-display-mode]) or (/oo:outline/oo:editor[@column-titles-display-mode = 'auto'] and count(/oo:outline/oo:columns/oo:column) > 2 )">
			
			<xsl:comment>Column Titles</xsl:comment>
			<table cellspacing="0" cellpadding="0" border="0" width="{$table-width}" class="heighthack row">
				
				<tr>
					
					<xsl:for-each select="$non-note-columns/oo:title">
						<xsl:variable name="pos" select="position()" />
						<td>
							<xsl:variable name="is-there-a-background">
								<xsl:call-template name="apply-background">
									<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:base-style/oo:style"/>  
									</xsl:call-template>
								</xsl:variable>
							
							<xsl:attribute name="class">
								<!-- column titles aren't effected by column styles in OO so disabling this -->
								<!--xsl:text>col</xsl:text>
								 <xsl:value-of select="position()"/-->
								<xsl:if test="$is-there-a-background = ''">
									<xsl:text> colbackground</xsl:text>
									<xsl:value-of select="position()"/>
									</xsl:if>
								<xsl:text> col_width</xsl:text>
								<xsl:value-of select="position()"/>
								
								</xsl:attribute>
							<!--xsl:attribute name="style">
							 <xsl:variable name="alignment" select="$non-note-columns[$pos]/oo:style/oo:value[@key = 'paragraph-alignment']"/>
							 <xsl:if test="$alignment">
							 <xsl:text>text-align: </xsl:text><xsl:value-of select="$alignment"/><xsl:text>; </xsl:text>
							 </xsl:if>
							 </xsl:attribute-->
							<!-- wrap the text futher in a div here so we can prioritize the column header style of the column style -->
							<div>
								<xsl:attribute name="class">
									<xsl:text>columntitle</xsl:text>
									<xsl:text> titlepadding</xsl:text>
									</xsl:attribute>
								<xsl:apply-templates select="."/>
								</div>
							</td>
						</xsl:for-each>
					</tr>
				</table>
			</xsl:if>
		</xsl:template>
	</xsl:stylesheet>
