<?xml version="1.0"?>
<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:oo="http://www.omnigroup.com/namespace/OmniOutliner/v3"
    exclude-result-prefixes="oo">
	
	<xsl:output method="xml" indent="yes"/>
	

	
	<xsl:param name="use-embedded-images"/>
	<xsl:template name="globalCSS">
		<style type="text/css">
			
			<xsl:choose>
				<xsl:when test="$use-embedded-images='yes'">
					.checked-image {
					content: url(<xsl:value-of select="$checked-image"/>);
					}
					.unchecked-image {
					content: url(<xsl:value-of select="$unchecked-image"/>);
					}
					.mixed-image {
					content: url(<xsl:value-of select="$mixed-image"/>);
					}
					.handle-image {
					content: url(<xsl:value-of select="$handle-image"/>);
					}
					.expand-image {
					content: url(<xsl:value-of select="$expand-image"/>);
					}
					.collapse-image {
					content: url(<xsl:value-of select="$collapse-image"/>);
					}
					.blank-image {
					content: url(<xsl:value-of select="$blank-image"/>);
					}
					</xsl:when>
				</xsl:choose>
			
			
			th {
			vertical-align: bottom;
			
			}
			
			td {
			vertical-align: top;
			}
			
			td,th {
			<xsl:if test="/oo:outline/oo:settings/oo:horizontal-grid-color">
				<xsl:text>border-bottom: 1px solid </xsl:text>
				<xsl:call-template name="rgb">
					<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:horizontal-grid-color/oo:color"/>
					</xsl:call-template>
				</xsl:if>
			<xsl:if test="/oo:outline/oo:settings/oo:vertical-grid-color">
				<xsl:text>border-left: 1px solid </xsl:text>
				<xsl:call-template name="rgb">
					<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:vertical-grid-color/oo:color"/>
					</xsl:call-template>
				</xsl:if>
			empty-cells: show;
			}
			
			.top-right-border {
			<xsl:if test="/oo:outline/oo:settings/oo:horizontal-grid-color">
				<xsl:text>border-top: 1px solid </xsl:text>
				<xsl:call-template name="rgb">
					<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:horizontal-grid-color/oo:color"/>
					</xsl:call-template>
				</xsl:if>
			<xsl:if test="/oo:outline/oo:settings/oo:vertical-grid-color">
				<xsl:text>border-right: 1px solid </xsl:text>
				<xsl:call-template name="rgb">
					<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:vertical-grid-color/oo:color"/>
					</xsl:call-template>
				</xsl:if>
			}
			
			.no-border {
			border-bottom: 0px;
			border-left: 0px;
			}
			
			
			
			
			table {
			<!-- set default font face and size when for when one isn't specified -->
			font-family: Helvetica, sans-serif;
			font-size: 12px;
			<!-- set all font setting from whole document settings, overriding the above if there's conflict -->
			<xsl:call-template name="apply-fonts">
				<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:base-style/oo:style"/> 
				</xsl:call-template>			
			
			}

			
			
			.wholeDocument {
			<xsl:call-template name="apply-styles">
				<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:base-style/oo:style"/> 
				</xsl:call-template>
			<xsl:call-template name="apply-background">
				<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:base-style/oo:style"/>  
				</xsl:call-template>
	
			}
		
			
			td.subcell {
			border: none;
			}
			
			td.content {
			padding-left: 4px;
			padding-bottom: 2px;
			padding-top: 1px;
			padding-right: 3px;
			}
			
			table.wide {
			width: 100%;
			}
			
			.full {
			height: 100%;
			}
			
			.heighthack {
			height: 8px;
			}
			
			div.titlepadding { <!-- padding for the column title table cells -->
			padding-right:3px;
			padding-left:6px;
			padding-bottom:3px;
			padding-top: 2px;
			}
			
			.summary_node {
			background: rgba(0,0,0,.12);
			margin-bottom: 1px;
			}
			
			div.column {   
			padding-right: 3px;
			padding-left: 4px;
			padding-top: 1px;
			padding-bottom: 2px;
			margin-right: 1px;
			}
			
			.labelpadding {
			padding-right: 1px;
			padding-top: 1px;
			padding-left: 2px;
			}
			
			.indicator {
			white-space: nowrap;
			text-align:right;
			margin-right: 0px;
			vertical-align: top;
			padding-top: 1px;
			padding-left: 0px;
			<xsl:call-template name="apply-gutter">
				<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:base-style/oo:style"/>  
				</xsl:call-template>
			}
			
			.wholedocgutter {
			<xsl:call-template name="apply-gutter">
				<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:base-style/oo:style"/>  
				</xsl:call-template>
			}
			
			div.row {
			}
			
			.expanded {
			display: inline;
			}
			.collapsed {
			display: none;
			}
			
			<!-- NYI from standard HTML export I think -->
			<xsl:if test="/oo:outline/oo:settings/oo:alternate-color/oo:color">
				.altRow {
				<xsl:text>background-color: </xsl:text>
				<xsl:call-template name="rgb">
					<xsl:with-param name="start-node" select="/oo:outline/oo:settings/oo:alternate-color/oo:color"/>
					<xsl:with-param name="important" select="true()"/>
					</xsl:call-template>
				}
				</xsl:if>
			
			
			.note { 
			padding-right: 3px; <!-- match td.content padding -->
			border: none; 
			<xsl:call-template name="apply-styles" >
				<xsl:with-param name="start-node" select="oo:outline/oo:columns/oo:column[@is-note-column = 'yes']/oo:style"/>
				</xsl:call-template>
			<xsl:call-template name="apply-background" >
				<xsl:with-param name="start-node" select="oo:outline/oo:columns/oo:column[@is-note-column = 'yes']/oo:style"/>
				</xsl:call-template>
			}
			
			/* Total table width is <xsl:value-of select="sum($non-note-columns/@width)" />
			Adjusted table width is <xsl:value-of select="$table-width" /> */
			
			.wholething {
				<!-- max-width: <xsl:value-of select="$table-width" />px;
				min-width: <xsl:value-of select="sum($non-note-columns/@width) - (.15 * $non-note-columns[1]/@width)" />px;
				-->
				width: <xsl:value-of select="$table-width" />;
			}
			
			
			table.row {
			<!-- width: 100%;-->
			width: <xsl:value-of select="$table-width" />;
			
			}
			
			<xsl:for-each select="$non-note-columns">
				<!-- uncomment this stuff to re-enable topic column dynamic width  bug://40050 -->
				<!--xsl:choose>
					<xsl:when test="position() = 1">
						.col_width1 { &#xa;
						min-width: <xsl:value-of select="$non-note-columns[1]/@width * .75"/>px; &#xa;  }&#xa;
						</xsl:when>
					<xsl:otherwise-->
						<xsl:text>&#xa;    .col_width</xsl:text><xsl:value-of select="position()"/><xsl:text> { &#xa;        </xsl:text>
						<xsl:call-template name="width" />
						<xsl:text>&#xa;    }&#xa;</xsl:text>
						<!--/xsl:otherwise>
					</xsl:choose-->
				</xsl:for-each>
			
			<xsl:for-each select="$non-note-columns">
				<xsl:text>&#xa;    .col</xsl:text><xsl:value-of select="position()"/><xsl:text> { &#xa;        </xsl:text>
				<xsl:call-template name="apply-styles" />
				<xsl:if test="@type = 'checkbox'">
					<xsl:text>text-align: center;&#xa;</xsl:text>
					</xsl:if>
				<xsl:text>&#xa;    }&#xa;</xsl:text>
				</xsl:for-each>
			
			<xsl:for-each select="$non-note-columns">
				<xsl:text>&#xa;    .colbackground</xsl:text><xsl:value-of select="position()"/><xsl:text> { &#xa;        </xsl:text>
				<xsl:call-template name="apply-background" />
				<xsl:if test="@type = 'checkbox'">
					<xsl:text>text-align: center;&#xa;</xsl:text>
					</xsl:if>
				<xsl:text>&#xa;    }&#xa;</xsl:text>
				</xsl:for-each>
			
			/* Level Styles */
			
			<xsl:for-each select="/oo:outline/oo:root/oo:style">
				
				<xsl:choose>
					<xsl:when test="position() = 1">
						<xsl:text>&#xa;    .columntitle { &#xa;        </xsl:text>
						<xsl:call-template name="apply-styles">
							<xsl:with-param name="start-node" select="."/>
							</xsl:call-template>
						<xsl:call-template name="apply-background">
							<xsl:with-param name="start-node" select="."/>
							</xsl:call-template>
						<xsl:text>&#xa;    }&#xa;</xsl:text>
						
						</xsl:when>
					<xsl:otherwise>
						<xsl:text>&#xa;    .level</xsl:text><xsl:value-of select="position() - 1"/><xsl:text> { &#xa;        </xsl:text>
						<xsl:call-template name="apply-styles">
							<xsl:with-param name="start-node" select="."/>
							</xsl:call-template>
						<xsl:text>&#xa;    }&#xa;</xsl:text>
						<xsl:text>&#xa;    .levelcolor</xsl:text><xsl:value-of select="position() - 1"/><xsl:text> { &#xa;        </xsl:text>
						<xsl:call-template name="apply-background">
							<xsl:with-param name="start-node" select="."/>
							</xsl:call-template>
						<xsl:text>&#xa;    }&#xa;</xsl:text>
						<xsl:text>&#xa;    .levelguttercolor</xsl:text><xsl:value-of select="position() - 1"/><xsl:text> { &#xa;        </xsl:text>
						<xsl:call-template name="apply-gutter">
							<xsl:with-param name="start-node" select="."/>
							</xsl:call-template>
						<xsl:text>&#xa;    }&#xa;</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			
			<xsl:for-each select="/oo:outline/oo:named-styles/oo:named-style">
				<xsl:variable name="style-name" select="@name" />
				<xsl:text>&#xa;    .ns-</xsl:text><xsl:value-of select="translate($style-name,' &#x9;&#xa;','-')"/><xsl:text> { &#xa;        </xsl:text>
				<xsl:call-template name="apply-styles" />
				<xsl:text>}&#xa;</xsl:text>
				</xsl:for-each>
				
			<xsl:for-each select="/oo:outline/oo:named-styles/oo:named-style">
				<xsl:variable name="style-name" select="@name" />
				<xsl:text>&#xa;    .ns-bg-</xsl:text><xsl:value-of select="translate($style-name,' &#x9;&#xa;','-')"/><xsl:text> { &#xa;        </xsl:text>
				<xsl:call-template name="apply-background" />
				<xsl:text>}&#xa;</xsl:text>
				</xsl:for-each>
				
			<xsl:for-each select="/oo:outline/oo:named-styles/oo:named-style">
				<xsl:variable name="style-name" select="@name" />
				<xsl:text>&#xa;    .ns-gutter-</xsl:text><xsl:value-of select="translate($style-name,' &#x9;&#xa;','-')"/><xsl:text> { &#xa;        </xsl:text>
				<xsl:call-template name="gutter-color" />
				<xsl:text>}&#xa;</xsl:text>
				</xsl:for-each>
			
			</style>
		</xsl:template>
	
	<xsl:template name="substitute">
		<xsl:param name="string" />
		<xsl:param name="from" select="'&#xA;'" />
		<xsl:param name="to">
			<br />
			</xsl:param>
		<xsl:choose>
			<xsl:when test="contains($string, $from)">
				<xsl:value-of select="substring-before($string, $from)" />
				<xsl:copy-of select="$to" />
				<xsl:call-template name="substitute">
					<xsl:with-param name="string"
					select="substring-after($string, $from)" />
					<xsl:with-param name="from" select="$from" />
					<xsl:with-param name="to" select="$to" />
					</xsl:call-template>
				</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$string" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:template>           
	<!-- Style grabbers -->
	
	<xsl:template match="oo:style"/>
	
	<xsl:template name="apply-styles">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:call-template name="inherited" ><xsl:with-param name="start-node" select="$start-node" /><xsl:with-param name="what-template">apply-styles</xsl:with-param></xsl:call-template>
		<xsl:call-template name="color" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<!--xsl:call-template name="background-color" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template-->
		<xsl:call-template name="font-family" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="text-decoration" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="font-style" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="font-weight" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="font-size" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="text-align" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="vertical-align" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>

		
		<!-- We can't do shadows until bug://bugs/25385 is done
		 <xsl:call-template name="text-shadow" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		 -->
		</xsl:template>
		
	<xsl:template name="apply-background">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:call-template name="inherited" ><xsl:with-param name="start-node" select="$start-node" /><xsl:with-param name="what-template">apply-background</xsl:with-param></xsl:call-template>
		<xsl:call-template name="background-color" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		</xsl:template>
		
	<xsl:template name="apply-gutter">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:call-template name="inherited" ><xsl:with-param name="start-node" select="$start-node" /><xsl:with-param name="what-template">apply-gutter</xsl:with-param></xsl:call-template>
		<xsl:call-template name="gutter-color" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		</xsl:template>
		
	<xsl:template name="apply-fonts">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:call-template name="inherited" ><xsl:with-param name="start-node" select="$start-node" /><xsl:with-param name="what-template">apply-fonts</xsl:with-param></xsl:call-template>
		<xsl:call-template name="font-family" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="text-decoration" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="font-style" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="font-weight" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="font-size" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		<xsl:call-template name="text-align" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		</xsl:template>
		
	<xsl:template name="apply-child-indent">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:call-template name="child-indent" ><xsl:with-param name="start-node" select="$start-node" /></xsl:call-template>
		</xsl:template>

	<xsl:template name="rgb">
		<!-- returns rgb or rgba suitable for use in css -->
		<xsl:param name="start-node" select="oo:color" />
		<xsl:param name="important" select="false()" />
		<xsl:param name="end-comma" select="true()" />
		
		<xsl:choose>
			<xsl:when test="$start-node and ($start-node/@a >= 0)">
				<xsl:text>rgba(</xsl:text>
				<xsl:value-of select="floor($start-node/@r * 255)" /><xsl:text>,</xsl:text>
				<xsl:value-of select="floor($start-node/@g * 255)" /><xsl:text>,</xsl:text>
				<xsl:value-of select="floor($start-node/@b * 255)" /><xsl:text>,</xsl:text>
				<xsl:value-of select="$start-node/@a" />
				
				<xsl:text>) </xsl:text>
				<xsl:if test="$important = true()">
					<xsl:text>!important</xsl:text>
					</xsl:if>
				<xsl:if test="$end-comma">
					<xsl:text>;  </xsl:text>
					</xsl:if>
				</xsl:when>
			<xsl:when test ="$start-node and ($start-node/@r >= 0)">
				<xsl:text>rgb(</xsl:text>
				<xsl:value-of select="floor($start-node/@r * 255)" /><xsl:text>,</xsl:text>
				<xsl:value-of select="floor($start-node/@g * 255)" /><xsl:text>,</xsl:text>
				<xsl:value-of select="floor($start-node/@b * 255)" />
				<xsl:text>) </xsl:text>
				<xsl:if test="$important = true()">
					<xsl:text>!important</xsl:text>
					</xsl:if>
				<xsl:if test="$end-comma">
					<xsl:text>;  </xsl:text>
					</xsl:if>
				</xsl:when>
			<!-- seeing odd <color w=0> settings on some files, this is to handle those -->
			<xsl:when test="$start-node and ($start-node/@w >= 0)">
				<xsl:text>rgb(</xsl:text>
				<xsl:value-of select="floor($start-node/@w * 255)" /><xsl:text>,</xsl:text>
				<xsl:value-of select="floor($start-node/@w * 255)" /><xsl:text>,</xsl:text>
				<xsl:value-of select="floor($start-node/@w * 255)" />
				<xsl:text>) </xsl:text>
				<xsl:if test="$important = true()">
					<xsl:text>!important</xsl:text>
					</xsl:if>
				<xsl:if test="$end-comma">
					<xsl:text>;  </xsl:text>
					</xsl:if>
				</xsl:when>
			<xsl:otherwise>
				<!-- This is if we encounter non-numerical color values. bug://12269 Just make it black-->
				<xsl:text>rgb(0,0,0)</xsl:text>
				<xsl:if test="$end-comma">
					<xsl:text>;  </xsl:text>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		
		
		</xsl:template>    
	
	<xsl:template name="width">
		<!-- add 15% to allow for the bold face of the headings -->
		<xsl:text>width: </xsl:text>
		<xsl:value-of select="@width + floor(@width * 0.15)" />
		<xsl:text>px;  /* Actual width is </xsl:text>
		<xsl:value-of select="@width" />
		<xsl:text> */</xsl:text>
		</xsl:template>
	
	<!--
	 BUG: Row numbering using legal format doesn't work quite right in rows nested underneath parent's with different numbering prefs
	 -->
	<xsl:template name="numbering">
		<xsl:param name="aos" />
		<xsl:param name="current-indentation" />
		
		<xsl:variable name="numbering">
			<xsl:call-template name="valueForKey">
				<xsl:with-param name="aos" select="$aos" />
				<xsl:with-param name="current-indentation" select="$current-indentation" />
				<xsl:with-param name="keyName" select="'heading-type(com.omnigroup.OmniOutliner)'" />
				</xsl:call-template>
			</xsl:variable>
		
		<xsl:variable name="prefix">
			<xsl:call-template name="valueForKey">
				<xsl:with-param name="aos" select="$aos" />
				<xsl:with-param name="current-indentation" select="$current-indentation" />
				<xsl:with-param name="keyName" select="'heading-prefix(com.omnigroup.OmniOutliner)'" />
				</xsl:call-template>
			</xsl:variable>
		
		<xsl:variable name="suffix">
			<xsl:call-template name="valueForKey">
				<xsl:with-param name="aos" select="$aos" />
				<xsl:with-param name="current-indentation" select="$current-indentation" />
				<xsl:with-param name="keyName" select="'heading-suffix(com.omnigroup.OmniOutliner)'" />
				</xsl:call-template>
			</xsl:variable>
		
		<xsl:variable name="numbering-lowercase">
			<xsl:call-template name="valueForKey">
				<xsl:with-param name="aos" select="$aos" />
				<xsl:with-param name="current-indentation" select="$current-indentation" />
				<xsl:with-param name="keyName" select="'heading-lowercase(com.omnigroup.OmniOutliner)'" />
				</xsl:call-template>
			</xsl:variable>
		
		<xsl:value-of select="$prefix" />
		
		<xsl:choose>
			<xsl:when test="$numbering = 'Numeric'">
				<xsl:number count="oo:item" />
				</xsl:when>
			<xsl:when test="$numbering = 'Legal'">
				<xsl:number count="oo:item" level="multiple" />
				</xsl:when>
			<xsl:when test="$numbering = 'Roman' and $numbering-lowercase = 'yes'">
				<xsl:number count="oo:item" format="i" />
				</xsl:when>
			<xsl:when test="$numbering = 'Roman' and $numbering-lowercase != 'yes'">
				<xsl:number count="oo:item" format="I" />
				</xsl:when>
			<xsl:when test="$numbering = 'Letters' and $numbering-lowercase = 'yes'">
				<xsl:number count="oo:item" format="a" />
				</xsl:when>
			<xsl:when test="$numbering = 'Letters' and $numbering-lowercase != 'yes'">
				<xsl:number count="oo:item" format="A" />
				</xsl:when>
			</xsl:choose>
		
		<xsl:value-of select="$suffix" />
		
		<xsl:text> </xsl:text>
		</xsl:template>
    
	<xsl:template name="valueForKey">
		<xsl:param name="aos" />
		<xsl:param name="current-indentation" />
		<xsl:param name="keyName" />
		<xsl:param name="default" />
		
		<xsl:variable name="row">
			<xsl:for-each select="$aos">
				<xsl:sort select="position()" order="ascending" data-type="number"/>
				<xsl:variable name="pos" select="count($aos) - position() + 1" />
				<xsl:value-of select="oo:style[$pos]/oo:value[@key = $keyName]/text()" />
				</xsl:for-each>
			</xsl:variable>
		
		<xsl:variable name="level" select="/oo:outline/oo:root/oo:style[$current-indentation + 2]/oo:value[@key = $keyName]/text()" />
		
		<xsl:variable name="base" select="/oo:outline/oo:settings/oo:base-style/oo:style/oo:value[@key = $keyName]/text()" />
		
		<xsl:choose>
			<xsl:when test="$row != ''">
				<xsl:value-of select="$row" />
				</xsl:when>
			<xsl:when test="$level != ''">
				<xsl:value-of select="$level" />
				</xsl:when>
			<xsl:when test="$base != ''">
				<xsl:value-of select="$base" />
				</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$default" />
				</xsl:otherwise>
			</xsl:choose>
		
		</xsl:template>
		
   
	<xsl:template name="text-decoration">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'underline-style'] or $start-node/oo:value[@key = 'strikethrough-style']">
			<xsl:text>text-decoration: </xsl:text>
			</xsl:if>
		<xsl:if test="$start-node/oo:value[@key = 'underline-style'] and $start-node/oo:value != 'none'">
			<xsl:text> underline</xsl:text>
			</xsl:if>
		<xsl:if test="$start-node/oo:value[@key = 'strikethrough-style'] and $start-node/oo:value != 'none'">
			<xsl:text> line-through</xsl:text>
			</xsl:if>
			
		<!-- doesn't work, can't set text-decoration to none to undo other values -->
		<xsl:if test="($start-node/oo:value[@key = 'underline-style'] and $start-node/oo:value = 'none') or ($start-node/oo:value[@key = 'strikethrough-style'] and $start-node/oo:value = 'none')">
			<xsl:text> none</xsl:text>
			</xsl:if>
		<xsl:if test="$start-node/oo:value[@key = 'underline-style'] or $start-node/oo:value[@key = 'strikethrough-style']">
			<xsl:text>;</xsl:text>
			</xsl:if>
		</xsl:template>    
	
	<xsl:template name="text-align">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'paragraph-alignment']">
			<xsl:text>text-align: </xsl:text>
			<xsl:choose>
				<xsl:when test="$start-node/oo:value = 'justified'">
					<xsl:text>justify</xsl:text>
					</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$start-node/oo:value[@key = 'paragraph-alignment']" />
					</xsl:otherwise>
				</xsl:choose>
			
			<xsl:text>;  </xsl:text>
			</xsl:if>
		</xsl:template>    
	
	<xsl:template name="font-style">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'font-italic'] and $start-node/oo:value = 'yes'">
			<xsl:text>font-style: italic;</xsl:text>
			</xsl:if>
		<xsl:if test="$start-node/oo:value[@key = 'font-italic'] and $start-node/oo:value = 'no'">
			<xsl:text>font-style: normal;</xsl:text>
			</xsl:if>
		</xsl:template>    
	
	<xsl:template name="font-weight">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'font-weight']">
			<xsl:text>font-weight: </xsl:text>
			<xsl:choose>
				<xsl:when test="($start-node/oo:value[@key = 'font-weight'] * 100) > 900">
					<xsl:text>900</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="($start-node/oo:value[@key = 'font-weight'] * 100)" />
					</xsl:otherwise>
				</xsl:choose>
			<xsl:text>;  </xsl:text>
			</xsl:if>
		</xsl:template>    
	
	<xsl:template name="font-size">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'font-size']">
			<xsl:text>font-size: </xsl:text>
			<xsl:value-of select="$start-node/oo:value[@key = 'font-size']" />
			<xsl:text>px;</xsl:text>
			</xsl:if>
		</xsl:template>    
	
	<!--
	 <xsl:template name="text-shadow">
	 <xsl:param name="start-node" select="oo:style" />
	 <xsl:if test="$start-node/oo:value[@key = 'shadow-color']">
	 <xsl:text> text-shadow: </xsl:text>
	 
	 <xsl:call-template name="rgb">
	 <xsl:with-param name="start-node" select="$start-node/oo:value[@key = 'shadow-color']/oo:color"/>
	 <xsl:with-param name="end-comma" select="false()"/>
	 </xsl:call-template>
	 <xsl:text> </xsl:text>
	 
	 <xsl:value-of select="$start-node/oo:value[@key = 'shadow-offset']" />
	 <xsl:text> </xsl:text>
	 
	 <xsl:value-of select="$start-node/oo:value[@key = 'shadow-radius']" />
	 <xsl:text>px; </xsl:text>
	 
	 
	 </xsl:if>
	 </xsl:template>
	 -->
	 
	
	<xsl:template name="font-family">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'font-family']">
			<xsl:text>font-family: "</xsl:text>
			<xsl:value-of select="$start-node/oo:value[@key = 'font-family']" />
			<xsl:text>", sans-serif</xsl:text>
			<xsl:text>;  </xsl:text>
			</xsl:if>
		</xsl:template>    
	
	<xsl:template name="color">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'font-fill']">
			<xsl:text>color:</xsl:text>
			<xsl:call-template name="rgb">
				<xsl:with-param name="start-node" select="$start-node/oo:value[@key = 'font-fill']/oo:color"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:template>    
	
	<xsl:template name="background-color">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'text-background-color']">
			<xsl:text>background-color:</xsl:text>
			<xsl:call-template name="rgb"><xsl:with-param name="start-node" select="$start-node/oo:value[@key = 'text-background-color']/oo:color"/></xsl:call-template>
			</xsl:if>
		</xsl:template>    
	
	<xsl:template name="gutter-color">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'item-gutter-color(com.omnigroup.OmniOutliner)']">
			<xsl:text>background-color:</xsl:text>
			<xsl:call-template name="rgb"><xsl:with-param name="start-node" select="$start-node/oo:value[@key = 'item-gutter-color(com.omnigroup.OmniOutliner)']/oo:color"/></xsl:call-template>
			</xsl:if>
		</xsl:template>    
	
	<xsl:template name="inherited">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:param name="what-template"/>
		<xsl:for-each select="$start-node/oo:inherited-style">
			<xsl:variable name="inherited-style-name" select="$start-node/oo:inherited-style/@name" />
			<xsl:for-each select="/oo:outline/oo:named-styles/oo:named-style">
				<xsl:if test="@name = $inherited-style-name">
					<xsl:choose>
						<xsl:when test="$what-template = 'apply-styles'">
							<xsl:call-template name="apply-styles"/>
							</xsl:when>
						<xsl:when test="$what-template = 'apply-background'">
							<xsl:call-template name="apply-background"/>
							</xsl:when>
						<xsl:when test="$what-template = 'apply-fonts'">
							<xsl:call-template name="apply-background"/>
							</xsl:when>
						<xsl:when test="$what-template = 'apply-gutter'">
							<xsl:call-template name="apply-gutter"/>
							</xsl:when>
						<xsl:when test="$what-template = 'apply-handle'">
							<xsl:call-template name="apply-handle"/>
							</xsl:when>
						<xsl:otherwise>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:template>  
	
	
	<!--xsl:template name="inherited-apply-styles">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:for-each select="$start-node/oo:inherited-style">
			<xsl:variable name="inherited-style-name" select="$start-node/oo:inherited-style/@name" />
			<xsl:for-each select="/oo:outline/oo:named-styles/oo:named-style">
				<xsl:if test="@name = $inherited-style-name">
					<xsl:call-template name="apply-styles"/>
					</xsl:if>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:template-->  

	
	<!-- for child indentation, NYI -->
	<!--xsl:template name="child-indent">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'item-child-indentation(com.omnigroup.OmniOutliner)']">
	 <xsl:value-of select="$start-node/oo:value[@key = 'item-child-indentation(com.omnigroup.OmniOutliner)']" />
	 </xsl:if>
	 </xsl:template--> 
	
	<xsl:template name="vertical-align">
		<xsl:param name="start-node" select="oo:style" />
		<xsl:if test="$start-node/oo:value[@key = 'baseline-superscript']">
			<xsl:text>vertical-align: </xsl:text>
			<xsl:choose>
				<xsl:when test="$start-node/oo:value &gt; 0">
					<xsl:text>super</xsl:text>
					</xsl:when>
				<xsl:when test="$start-node/oo:value &lt; 0">
					<xsl:text>sub</xsl:text>
					</xsl:when>
				<xsl:otherwise>
					</xsl:otherwise>					
				</xsl:choose>
			<xsl:text>;  </xsl:text>
			</xsl:if>
		</xsl:template>
	
	
	<xsl:template name="status-checkbox">
		<xsl:param name="state"/>
		<xsl:if test="$is-status-visible != 'no' ">
			<xsl:choose>
				<xsl:when test="$state='indeterminate'">
					<xsl:choose>
						<xsl:when test="$use-embedded-images='yes'">
							<img border="0" style="margin-left: 2px; margin-right: 2px;" alt="-" class="mixed-image" title="mixed"/>
							</xsl:when>
						<xsl:otherwise>
							<img border="0" style="margin-left: 2px; margin-right: 2px;" alt="-" src="Mixed.png" />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
				<xsl:when test="$state='checked'">
					<xsl:choose>
						<xsl:when test="$use-embedded-images='yes'">
							<img border="0" style="margin-left: 2px; margin-right: 2px;" alt="X" class="checked-image" title="checked"/>
							</xsl:when>
						<xsl:otherwise>
							<img border="0" style="margin-left: 2px; margin-right: 2px;" alt="X" src="Checked.png" />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
				<xsl:when test="$state='none'">
					<xsl:choose>
						<xsl:when test="$use-embedded-images='yes'">
							<img border="0" style="margin-left: 2px; margin-right: 2px;" alt="" class="blank-image" />
							</xsl:when>
						<xsl:otherwise>
							<img border="0" style="margin-left: 2px; margin-right: 2px;" alt="" src="blank.png" />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$use-embedded-images='yes'">
							<img border="0" style="margin-left: 2px; margin-right: 2px;" alt=" " class="unchecked-image" title="unchecked"/>
							</xsl:when>
						<xsl:otherwise>
							<img border="0" style="margin-left: 2px; margin-right: 2px;" alt=" " src="Unchecked.png" />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
		</xsl:template>
	
	</xsl:stylesheet>